@@ -38,7 +38,7 @@ from simplekml import Kml, Style, IconStyle, Icon, LineStyle
 from tropofy.app import AppWithDataSets, Step, StepGroup
 from tropofy.widgets import ExecuteFunction, SimpleGrid, KMLMap, Chart
 from tropofy.database.tropofy_orm import DataSetMixin
-from tropofy.database import read_write_xl
+from tropofy.file_io import read_write_xl
 import os
 
 
@@ -303,8 +303,8 @@ def invoke_localsolver_using_lsp_file(data_set, input_file_name):
 
 
 def load_brisbane_data(data_set):  # Post code geocode data sourced from http://blog.orite.com.au/wp-content/uploads/2009/01/aupcgeo.7z
-    read_write_xl.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('max_cut_brisbane_example_data.xlsx'))
+    read_write_xl.ExcelReader.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('max_cut_brisbane_example_data.xlsx'))
 
 
 def load_euro_data(data_set):  # Post code geocode data sourced from http://blog.orite.com.au/wp-content/uploads/2009/01/aupcgeo.7z
-    read_write_xl.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('max_cut_euro_example_data.xlsx'))    
+    read_write_xl.ExcelReader.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('max_cut_euro_example_data.xlsx'))
